--
--  AppDelegate.applescript
--  pdfviewAgainstAppleBug
--
--  Created by Takaaki Naganoya on 2019/11/21.
--  Copyright ˝ 2019 Takaaki Naganoya. All rights reserved.
--

script AppDelegate
	property parent : class "NSObject"
	property |NSURL| : a reference to current application's class "NSURL"
	property PDFDocument : a reference to current application's class "PDFDocument"
	
	-- IBOutlets
	property theWindow : missing value
	property pdfView : missing value
	property pdfPageText : missing value
	
	property curPageNum : 0
	
	on applicationWillFinishLaunching:aNotification
		set curPageNum to 0
		set noter1 to current application's NSNotificationCenter's defaultCenter()
		noter1's addObserver:me selector:"pdfChange:" |name|:(current application's PDFViewDocumentChangedNotification) object:pdfView
		noter1's addObserver:me selector:"pdfPageChange:" |name|:(current application's PDFViewPageChangedNotification) object:pdfView
	end applicationWillFinishLaunching:
	
	on applicationShouldTerminate:sender
		-- Insert code here to do any housekeeping before your application quits 
		return current application's NSTerminateNow
	end applicationShouldTerminate:
	


	on clicked:sender
		set aTag to (tag of sender) as integer
		if aTag = 100 then
			set aFile to POSIX path of (choose file of type "com.adobe.pdf")
			dispPDFWithPOSIXpath_(aFile)
			
		else if aTag = 300 then
			goToPreviousPage(pdfView)
			
		else if aTag = 400 then
			goToNextPage(pdfView)
			
		end if
	end clicked:
	
	
	on |application|:theApp openFiles:fileList
		set aFile to first item of fileList
		my dispPDFWithPOSIXpath:(aFile)
	end |application|:openFiles:
	
	
	on pdfPageChange:notification
		set curObject to notification's object
		my dispPDFPageNumber(curObject)
	end pdfPageChange:
	
	
	on pdfChange:notification
		set curObject to notification's object
		my dispPDFPageNumber(curObject)
	end pdfChange:
	
	
	on goToPreviousPage(aView)
		set curPage to getCurrentPage(aView)
		set curDoc to aView's |document|
		set curPageNumber to curDoc's indexForPage:curPage
		set curPageNumber to curPageNumber - 1
		aView's goToPage:(curDoc's pageAtIndex:curPageNumber)
	end goToPreviousPage
	
	
	on goToNextPage(aView)
		set curPage to getCurrentPage(aView)
		set curDoc to aView's |document|
		set curPageNumber to curDoc's indexForPage:curPage
		set curPageNumber to curPageNumber + 1
		aView's goToPage:(curDoc's pageAtIndex:curPageNumber)
	end goToNextPage
	
	
	on dispPDFWithPOSIXpath:(aFileString as string)
		set aStr to (current application's NSString's stringWithString:aFileString)'s lastPathComponent() as string
		theWindow's setTitle:aStr
		set theURL to |NSURL|'s fileURLWithPath:(aFileString)
		set aPDFdoc to PDFDocument's alloc()'s initWithURL:theURL
		pdfView's setDocument:aPDFdoc
	end dispPDFWithPOSIXpath:
	
	
	--PDFページ数を表示する
	on dispPDFPageNumber(aView)
		set curDoc to aView's |document|
		set curPage to my getCurrentPage(aView)
		set curPageNumber to curDoc's indexForPage:curPage
		copy curPageNumber to curPageNum
		pdfPageText's setStringValue:((curPageNumber + 1) as string)
	end dispPDFPageNumber
	
	
	on getCurrentPage(aPDFView)
		set curDoc to aPDFView's |document|
		set curPages to (aPDFView's visiblePages()) as list
		set curPage to contents of first item of curPages
		return curPage
	end getCurrentPage
	
end script
